<?php
/**
 * class-slc-settings.php
 *
 * @since: 0.1.0
 * @version: 0.1.0
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

class Skype_Live_chat_Settings
{
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    /**
     * Start up
     */
    public function __construct()
    {
        add_action('admin_menu', array($this, 'add_plugin_page'));
        add_action('admin_init', array($this, 'page_init'));
    }

    /**
     * Add options page
     */
    public function add_plugin_page()
    {
        add_options_page(
            __('Skype Live Chat Settings', 'skype-live-chat'),
            __('Skype Live Chat', 'skype-live-chat'),
            'manage_options',
            'skype-live-chat',
            array($this, 'create_admin_page')
        );
    }

    public function create_admin_page()
    {
        $this->options = get_option('skype_live_chat');
        ?>
        <div class="wrap">
            <h1><?php _e('Skype Live Chat Settings', 'skype-live-chat'); ?></h1>
            <form method="post" action="options.php">
                <?php
                settings_fields('skype_live_chat');
                do_settings_sections('skype-live-chat');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }

    public function page_init()
    {
        register_setting(
            'skype_live_chat', // Option group
            'skype_live_chat', // Option name
            array($this, 'sanitize') // Sanitize
        );

        add_settings_section(
            'setting_section_id', // ID
            __('General Settings', 'skype-live-chat'),
            array($this, 'print_section_info'), // Callback
            'skype-live-chat' // Page
        );
        add_settings_field(
            'skype_id',
            'Skype ID',
            array($this, 'skype_id'),
            'skype-live-chat',
            'setting_section_id'
        );
    }

    public function sanitize($input)
    {
        $new_input = array();

        if (isset($input['skype_id']))
            $new_input['skype_id'] = sanitize_text_field($input['skype_id']);

        return $new_input;
    }

    public function print_section_info()
    {
        print 'Enter your settings below:';
    }

    public function skype_id()
    {
        printf(
            '<input type="text" id="skype_id" name="skype_live_chat[skype_id]" value="%s" />',
            isset($this->options['skype_id']) ? esc_attr($this->options['skype_id']) : ''
        );
    }
}

if (is_admin()) {
    new Skype_Live_chat_Settings();
}